@@ -1,26 +1,3 @@
-#
-# MIT License
-#
-# Copyright (c) 2018-2020 Franck Nijhof
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-
 """
 Add-on Module.
 
@@ -44,7 +21,6 @@ from github.Repository import Repository
 from jinja2 import BaseLoader, Environment
 
 from .const import CHANNEL_BETA, CHANNEL_EDGE
-from .dockerhub import DockerHub
 
 
 class Addon:
@@ -120,14 +96,6 @@ class Addon:
         self.current_release = self.latest_release
         self.current_commit = self.latest_commit
 
-        if not self.is_live():
-            click.echo(
-                crayons.red(
-                    "Not all Docker images are available on DockerHub aborting..."
-                )
-            )
-            sys.exit(1)
-
         self.ensure_addon_dir()
         self.generate_addon_config()
         self.update_static_files()
@@ -333,23 +301,6 @@ class Addon:
         else:
             click.echo(crayons.blue("Skipping"))
 
-    def is_live(self):
-        """Check if the latest add-on version is actually on Docker Hub."""
-        click.echo(
-            "Checking if all Docker images are available on Docker Hub...", nl=False
-        )
-        for arch in self.archs:
-            image = self.image.replace("{arch}", arch)
-            if not DockerHub.image_exists_on_dockerhub(
-                self.image.replace("{arch}", arch), self.current_version
-            ):
-                click.echo(
-                    crayons.red("Missing: %s:%s" % (image, self.current_version))
-                )
-                return False
-        click.echo(crayons.green("OK!"))
-        return True
-
     def generate_readme(self):
         """Re-generate the add-on readme based on a template."""
         click.echo("Re-generating add-on README.md file...", nl=False)
